# Zenif 0.5.2-beta1

Zenif (pronounced "Zenith") is a Python library designed to enhance the way you write your code. Please take it into consideration that I developed Zenif as a personal side-project of mine to help me with other projects, so some features might not work as expected as I have not full tested everything.

## Installation

Zenif requires Python 3.12 or higher. To install the latest version, install with `pip` or your favorite PyPi package manager.

```sh
pip install zenif
```

This command will download and install Zenif along with its dependencies.

## Documentation

### Modules

Zenif is a multi-faceted library, covering multiple areas of the developer experience that need improving.

- [CLI](https://github.com/DomBom16/zenif/blob/main/docs/modules/cli.md): Create command line interfaces and interactive prompts
- [Log](https://github.com/DomBom16/zenif/blob/main/docs/modules/log.md): Enhance your debugging game with a highly customizable logger
- [Decorators](https://github.com/DomBom16/zenif/blob/main/docs/modules/decorators.md): Give your functions extra functionality on the fly
- [Schema](https://github.com/DomBom16/zenif/blob/main/docs/modules/schema.md): Validate your user's inputs with intuitive syntax

## License

Zenif is released under the MIT License. See the [LICENSE](LICENSE) file for more details.

<!-- Only add acknowledgements once someone is acknowledged :( -->

<!-- ## Acknowledgements

We would like to thank all the contributors who have helped to make Zenif better. Your time and effort are greatly appreciated.

Thank you for contributing, **User1**, **User2**, ... , and **UserN**.-->
